/*
   Situare - A location system for Facebook
   Copyright (C) 2010  Ixonos Plc. Authors:

       Jussi Laitinen - jussi.laitinen@ixonos.com

   Situare is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   version 2 as published by the Free Software Foundation.

   Situare is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Situare; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
   USA.
*/

#include <QDebug>
#include <QTimer>

#include "error.h"
#include "gpsposition.h"
#include "gpspositionprivatestub.h"

const GeoCoordinate COORDINATE(65.0105, 25.5091);

GPSPositionPrivate::GPSPositionPrivate(QObject *parent)
    : QObject(parent),
      m_running(false)
{
    qDebug() << __PRETTY_FUNCTION__;

    m_parent = static_cast<GPSPosition*>(parent);
    m_timer = new QTimer(this);
    connect(m_timer, SIGNAL(timeout()), this, SLOT(timeout()));
    m_timer->setInterval(5000);
}

bool GPSPositionPrivate::isInitialized() const
{
    qDebug() << __PRETTY_FUNCTION__;

    return true;
}

bool GPSPositionPrivate::isRunning() const
{
    qDebug() << __PRETTY_FUNCTION__;

    return m_running;
}

void GPSPositionPrivate::setUpdateInterval(int interval)
{
    qDebug() << __PRETTY_FUNCTION__;

    Q_UNUSED(interval);
    m_timer->setInterval(interval);
}

void GPSPositionPrivate::setMode(GPSPosition::Mode mode, const QString &filePath)
{
    qDebug() << __PRETTY_FUNCTION__;

    Q_UNUSED(mode);
    Q_UNUSED(filePath);
}

void GPSPositionPrivate::setPowerSave(bool enabled)
{
    qDebug() << __PRETTY_FUNCTION__;

    if (enabled)
        stop();
    else
        start();
}

void GPSPositionPrivate::start()
{
    qDebug() << __PRETTY_FUNCTION__;

    m_running = true;
    m_timer->start();
}

void GPSPositionPrivate::stop()
{
    qDebug() << __PRETTY_FUNCTION__;

    m_running = false;
    m_timer->stop();
}

void GPSPositionPrivate::timeout()
{
    emit m_parent->position(COORDINATE, 100.0);
}

GeoCoordinate GPSPositionPrivate::lastPosition() const
{
    qDebug() << __PRETTY_FUNCTION__;

    return COORDINATE;
}

void GPSPositionPrivate::requestLastPosition()
{
    qDebug() << __PRETTY_FUNCTION__;

    emit m_parent->position(COORDINATE, 100.0);
}

void GPSPositionPrivate::requestUpdate()
{
    qDebug() << __PRETTY_FUNCTION__;

    start();
}
