/*
    Situare - A location system for Facebook
    Copyright (C) 2010  Ixonos Plc. Authors:

        Henri Lampela - henri.lampela@ixonos.com
        Sami Rämö - sami.ramo@ixonos.com

    Situare is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    version 2 as published by the Free Software Foundation.

    Situare is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Situare; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

#include <QDebug>
#include <QSettings>

#include "common.h"

#include "networkcookiejar.h"

const QString COOKIES_SETTING = "cookies";

NetworkCookieJar::NetworkCookieJar(QObject *parent)
    : QNetworkCookieJar(parent)
{
    qWarning() << __PRETTY_FUNCTION__;

    loadCookies();
}

NetworkCookieJar::~NetworkCookieJar()
{
    qWarning() << __PRETTY_FUNCTION__;

    saveCookies();
}

void NetworkCookieJar::clearCookiesSetting()
{
    qWarning() << __PRETTY_FUNCTION__;

    QSettings settings(SETTINGS_ORGANIZATION_NAME, SETTINGS_APPLICATION_NAME);
    settings.remove(COOKIES_SETTING);
}

void NetworkCookieJar::loadCookies()
{
    qWarning() << __PRETTY_FUNCTION__;

    QSettings settings(SETTINGS_ORGANIZATION_NAME, SETTINGS_APPLICATION_NAME);

    QStringList list = settings.value(COOKIES_SETTING).toStringList();

    if(!list.isEmpty()) {
        QList<QNetworkCookie> cookieList;
        for(int i = 0; i < list.count(); i++) {
            cookieList.append(QNetworkCookie::parseCookies(list.at(i).toAscii()));
        }

        setAllCookies(cookieList);
    }
}

void NetworkCookieJar::saveCookies()
{
    qWarning() << __PRETTY_FUNCTION__;

    QList<QNetworkCookie> cookieList = allCookies();
    QStringList list;

    for(int i = 0; i < cookieList.count(); i++) {
        QNetworkCookie cookie = cookieList.at(i);
        QByteArray byteArray = cookie.toRawForm(QNetworkCookie::Full);
        list.append(QString(byteArray));
    }
    list.removeDuplicates();

    QSettings settings(SETTINGS_ORGANIZATION_NAME, SETTINGS_APPLICATION_NAME);
    settings.setValue(COOKIES_SETTING, list);
}
