/*
    Situare - A location system for Facebook
    Copyright (C) 2010  Ixonos Plc. Authors:

        Henri Lampela - henri.lampela@ixonos.com
        Sami Rämö - sami.ramo@ixonos.com

    Situare is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    version 2 as published by the Free Software Foundation.

    Situare is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Situare; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
    USA.
*/

#ifndef NETWORKCOOKIEJAR_H
#define NETWORKCOOKIEJAR_H

#include <QNetworkCookieJar>

/**
* @brief Sub-class of QNetworkCookieJar, needed for cookie saving
*
* @author Henri Lampela
* @author Sami Rämö - sami.ramo (at) ixonos.com
*/
class NetworkCookieJar : public QNetworkCookieJar
{
    Q_OBJECT

public:
    /**
    * @brief Constructor
    *
    * Calls loadCookies().
    *
    * @param parent Instance of parent
    */
    explicit NetworkCookieJar(QObject *parent = 0);

    /**
      * @brief Destructor
      *
      * Calls saveCookies().
      */
    ~NetworkCookieJar();

/*******************************************************************************
 * MEMBER FUNCTIONS AND SLOTS
 ******************************************************************************/
public:
    /**
      * @brief Clear cookies from settings
      */
    static void clearCookiesSetting();

private:
    /**
      * @brief Load cookies from settings to jar
      */
    void loadCookies();

    /**
      * @brief Save cookies from jar to settings
      */
    void saveCookies();
};

#endif // NETWORKCOOKIEJAR_H
